Discover Packages
github.com/threetides/gonet
cmd
package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Jul 16, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Execute adds all child commands to the root command and sets flags appropriately.
This is called by main.main(). It only needs to happen once to the rootCmd.
type Project struct {
ModuleName string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.